@@ -34,7 +34,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.13';
+our $VERSION = '1.14';
 
 =head1 SYNOPSIS
 
@@ -193,6 +193,12 @@ Data dumper.
 
 Internal data dumper.
 
+=head2 dye
+
+Color a string.
+
+    say dye( "HEY", "RED" );
+
 =head2 g
 
 Perform a get request.
@@ -368,6 +374,12 @@ sub import {
             Devel::Peek::Dump( @_ );
         },
 
+        # Color.
+        dye => sub {
+            require Term::ANSIColor;
+            Term::ANSIColor::colored( @_ );
+        },
+
         ######################################
         #           Web Related
         ######################################
